Installation
============

MUSICA source code may be cloned from its public GitHub repository
and configured and built with the cmake utility.
In brief:

.. code-block:: console
 
    $ git clone https://github.com/NCAR/musica.git
    $ cd musica
    $ mkdir build
    $ cd build
    $ ccmake ..
    $ make
    $ make install
